* Add to documentation:
  * README.md with examples
  * DEVELOP.md with instructions on how to start developing
  * rule_X models
  * Dataset functions
  * Base classes functions
* Publish to pypi
* Implement numpy backend
* Implement polars backend
* Implement BFS strategy for Tree.predict without recursion
